@@ -49,9 +49,9 @@ FunctionTools::FunctionTools(QWidget *parent )
 	
 	init( CalculateArea );
 	
-	connect( m_widget->min, SIGNAL(editingFinished()), this, SLOT(rangeEdited()) );
-	connect( m_widget->max, SIGNAL(editingFinished()), this, SLOT(rangeEdited()) );
-	connect( m_widget->list, SIGNAL(currentRowChanged(int)), this, SLOT(equationSelected(int)) );
+	connect(m_widget->min, &EquationEdit::editingFinished, this, &FunctionTools::rangeEdited);
+	connect(m_widget->max, &EquationEdit::editingFinished, this, &FunctionTools::rangeEdited);
+	connect(m_widget->list, &QListWidget::currentRowChanged, this, &FunctionTools::equationSelected);
 }
 
 
@@ -234,6 +234,3 @@ void FunctionTools::calculateArea( const EquationPair & equation )
 	m_widget->rangeResult->setText( i18n("Area is %1", area ) );
 }
 //END class FunctionTools
-
-
-#include "functiontools.moc"
